REM GMT EXAMPLE 52
REM
REM Purpose:     Mixing images and overlaying them on the Earth
REM GMT modules: grdgradient, grdimage, grdmath, grdmix, grdsample, solar

set res=20m 
REM Change to 15m, 10m, 06m, 05m, 04m, 03m, 02m, 01m, 30s for higher resolutions

gmt begin ex52

  REM Use the location of the Sun at noon on Jun 22, 2000, Hawaii Standard Time
  REM Make a global grid with a smooth 2-degree transition across day/night boundary.
  for /f "tokens=*" %%i in ('gmt solar -C -o0:1 -I+d2000-06-22T24:00+z-10') do set coord=%%i
  gmt grdmath -Rd -I%res% -r 30.538 23.425 2 DAYNIGHT = w.grd

  REM We will create an intensity grid based on a DEM so that we can see structures in the oceans
  gmt grdgradient @earth_relief_%res% -Nt0.5 -A45 -Gintens.h5
  
  REM Blend the earth_day and earth_night geotiffs using the weights, so that when w is 1
  REM we get the earth_day, and then adjust colors based on the intensity.

  gmt grdmix @earth_day_%res% @earth_night_%res% -Ww.grd -Iintens.h5 -Gview.tif

  REM Plot this image on an Earth with view from over Mexico
  gmt grdimage view.tif -JG80W/30N/18c -Bafg
  REM Clean up after use
  del w.grd intens.grd 
gmt end show
